@@ -2,9 +2,7 @@
 Some utilities to make programming with tuple spaces
 easier.
 """
-import os
 import signal
-import multiprocessing
 
 class TimeoutError(Exception): pass
 
@@ -23,7 +21,7 @@ class timeout(object):
         signal.alarm(0)
         signal.signal(signal.SIGALRM, self.oldsig)
         if self.boom:
-            raise TimeoutError("timed out")
+            raise TimeoutError("computation timed out")
 
     def bailout(self, *args):
         self.boom = True
